@@ -40,6 +40,7 @@
 #include <sched.h>
 #include <signal.h>
 #include <dirent.h>
+#include <sys/sysmacros.h>
 
 #include <corosync/cpg.h>
 
@@ -93,6 +94,7 @@ enum {
         log_debug_ind,
         timewarn_ind,
         protocol_ind,
+	enable_inaddr_any_ind,
         debug_logfile_ind,
         enable_fscontrol_ind,
         enable_plock_ind,
