@@ -1281,6 +1281,11 @@ static void set_opt_defaults(void)
 			-1, "detect",
 			"dlm kernel lowcomms protocol: tcp, sctp, detect");
 
+	set_opt_default(enable_inaddr_any_ind,
+			"enable_inaddr_any", '\0', req_arg_int,
+			0, NULL,
+			"local node to use inaddr_any: 0=disable, 1=auto, 4=IPv4, 6=IPv6");
+
 	set_opt_default(debug_logfile_ind,
 			"debug_logfile", 'L', no_arg,
 			0, NULL,
